#' @importFrom prcbench

library(testthat)

test_check("prcbench")
